@@ -11,7 +11,7 @@ import warnings
 import logging
 import getpass
 import datetime
-from .tools.geom_dtf import feature_id, geom_prop, mask_layers
+from .tools.geom_dtf import feature_id, geom_prop
 from .readers.read_scc_db import read_scc_db
 from .readers.get_files import database
 from .readers.parse_config import parse_config
@@ -20,6 +20,7 @@ from .export.update_scc_db import update
 from .readers.read_config import config
 from .debug import log_pack
 from .version import __version__
+#from .debug.plot import debug_layers
 
 logger = logging.getLogger()
 
@@ -82,21 +83,19 @@ def main(args=None):
     
 # Change logging level according to config file
     logger.setLevel(cfg.scc['log-level'].upper())
-
-# Threshold to select the sharpest peaks (63% less sharp than the sharpest)
-    margin = 0.63
     
 # Get array of input files from an scc database query
     logger.info("----------------------------------------------------------------")
     logger.info("------ Processing started on %s ------" % start_time)
     logger.info("Quering the measurement paths in the SCC database ")
     try:
-        files, rpath, alphas, det_lims, ids = database(meas_id, cfg = cfg)
+        files, rpath, alphas, snr_factor, wct_peak_margin, prod_type_id, ids = \
+            database(meas_id, cfg = cfg)
     except Exception as e:
         logger.error("Error while executing a measurement ID query in the SCC database ")
         sys.exit(4)                
-    logger.info("Measurement paths succesfully collected ")    
-    
+    logger.info("Measurement paths succesfully collected ") 
+ 
 ###############################################################################
 # A) Preprocessing
 ###############################################################################
@@ -104,13 +103,14 @@ def main(args=None):
 # Optical Profiles
     logger.info("Section A: Reading the SCC files ")
     try:
-        dt_start_arr, alt_arr, prod_arr, metadata, wave = \
+        dt_start_arr, alt_arr, prod_arr, prod_err_arr, metadata, wave = \
             read_scc_db(files, end_fill = alphas)
+    
     except Exception as e:
         logger.error("Error while reading the SCC files ")
         sys.exit(5)   
     logger.info("       All SCC files succesfully read ")
-    
+
 ###############################################################################
 # B) Geometrical retrievals
 ############################################################################### 
@@ -121,62 +121,58 @@ def main(args=None):
     for i in range(0, len(files)):
         logger.info(f"****** Proccessing file: {os.path.basename(files[i])} ******")
         logger.info("Section B: Proceeding to the layering algorithm ")
-
-        norm = prod_arr[i]/det_lims[i]
         
 # B.1) Identify layers and each base and top
         try:
-            rl_flag, bases, tops, wct = feature_id(alt_arr[i], norm,
-                                                   alpha = alphas[i], 
-                                                   peak_margin = margin,
-                                                   log = logger)
+            rl_flag, bases, tops, wct = \
+                feature_id(alt_arr[i], sig = prod_arr[i], err = prod_err_arr[i],
+                           alpha = alphas[i], snr_factor = snr_factor, 
+                           wct_peak_margin = wct_peak_margin, log = logger)
         except Exception as e:
             logger.error("Error while identifying layer boundaries ")
             sys.exit(6)  
         logger.info("       Potential layer boundaries succesfully identified ")
 
-# B.2) Use base and top to the profile to extract aditional 
-# geometrical properties
+# B.2) Use base and top to the profile to extract aditional geometrical properties
         try:
-            geom = geom_prop(rl_flag, bases, tops, alt_arr[i], norm, log = logger)
+            geom = geom_prop(rl_flag, bases, tops, alt_arr[i], prod_arr[i], log = logger)
+        # debug_layers(alt = alt_arr[i], sig = prod_arr[i], std = prod_err_arr[i], 
+        #               wct = wct, geom = geom, max_alt = 10., 
+        #               snr_factor = snr_factor, prod_ulim = 5., 
+        #               date = meas_id, dir_out = './', dpi_val = 300)
+
         except Exception as e:
             logger.error("Error while calculating layer properties ")
             sys.exit(7)  
         logger.info("       Layer properties succesfully calculated ")
         
-# B.3) Filter out irregular features
-        try:
-            geom = mask_layers(geom, log = logger)
-        except Exception as e:
-            logger.error("Error while filtering out irregular layers ")
-            sys.exit(8)  
-        logger.info("       Irregular layers succesfully filtered out ")
-    
-        
 ###############################################################################
 # C) Exporting
 ###############################################################################
         logger.info("Section C: Exporting layer properties ")
-            
+
         if len(geom) > 0:
 # C.1) Export to netcdf
 # C.1.i) Netcdf filename
-            # try:
-            fname = nc_name(metadata[i], prod_id = ids[i], wave = wave[i], 
-                            ver = __version__)
-            # except Exception as e:
-                # logger.error("Error while creating the netcdf filename ")
-                # sys.exit(9)  
-            # logger.info("       Netcdf filename succesfully created ")
+            try:
+                fname = nc_name(metadata[i], prod_id = ids[i], 
+                                prod_type_id = prod_type_id[i], wave = wave[i])
+            except Exception as e:
+                logger.error("Error while creating the netcdf filename ")
+                sys.exit(8)  
+            logger.info("       Netcdf filename succesfully created ")
             
 # C.1.ii) Netcdf file        
             try:
                 dir_out = os.path.join(cfg.scc['output-dir'],meas_id)
-                geom_dts = export_nc(geom, metadata[i], alphas[i], wave[i], 
-                                     det_lims[i], fname, dir_out)
+                geom_dts = \
+                    export_nc(geom, metadata = metadata[i], alpha = alphas[i], 
+                              wave = wave[i], snr_factor = snr_factor, 
+                              wct_peak_margin = wct_peak_margin, 
+                              fname = fname, dir_out = dir_out)
             except Exception as e:
                 logger.error("Error while creating the netcdf files ")
-                sys.exit(10)
+                sys.exit(9)
             logger.info("       Exporting in NetCDF format succesfully completed ")
             
 # C.2) Save in lists
@@ -191,7 +187,7 @@ def main(args=None):
                 update(fpath, meas_id = meas_id, prod_id = ids[i], cfg = cfg)
             except Exception as e:
                 logger.error("Error while updating the scc database ")
-                sys.exit(11)         
+                sys.exit(10)         
             logger.info("       SCC database succesfully updated ")
         else:
             logger.warning("       No layers were identified for this measurement! ")
